@@ -1,6 +1,6 @@
 import click
 
-__version__ = "0.2.5"
+__version__ = "0.2.8"
 
 
 @click.command()
@@ -10,4 +10,4 @@ def cli():
 
 
 if __name__ == "__main__":
-    cli()
+    cli()  # pragma: no cover
